==> net.bluemind.p2.we.settings-4.9.3879.zip: net/bluemind/core/container/model/gwt/js/JsContainerDescriptor.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.core.container.model.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsContainerDescriptor extends net.bluemind.core.container.model.gwt.js.JsBaseContainerDescriptor  {

	protected JsContainerDescriptor() {}

	public final native Boolean getWritable()
	/*-{
	return this["writable"];
	}-*/;

	public final native void setWritable(Boolean writable)
	/*-{
       this["writable"] = writable;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.acl.gwt.js.JsVerb> getVerbs()
	/*-{
	return this["verbs"];
	}-*/;

	public final native void setVerbs(com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.acl.gwt.js.JsVerb> verbs)
	/*-{
       this["verbs"] = verbs;
	}-*/;

	public final native boolean getOfflineSync()
	/*-{
	return this["offlineSync"];
	}-*/;

	public final native void setOfflineSync(boolean offlineSync)
	/*-{
       this["offlineSync"] = offlineSync;
	}-*/;

	public static native  JsContainerDescriptor create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.we.settings-5.4.2760.zip: net/bluemind/core/container/model/gwt/js/JsContainerDescriptor.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.core.container.model.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsContainerDescriptor extends net.bluemind.core.container.model.gwt.js.JsBaseContainerDescriptor  {

	protected JsContainerDescriptor() {}

	public final native Boolean getWritable()
	/*-{
	return this["writable"];
	}-*/;

	public final native void setWritable(Boolean writable)
	/*-{
       this["writable"] = writable;
	}-*/;

	public final native com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.acl.gwt.js.JsVerb> getVerbs()
	/*-{
	return this["verbs"];
	}-*/;

	public final native void setVerbs(com.google.gwt.core.client.JsArray<net.bluemind.core.container.model.acl.gwt.js.JsVerb> verbs)
	/*-{
       this["verbs"] = verbs;
	}-*/;

	public final native boolean getOfflineSync()
	/*-{
	return this["offlineSync"];
	}-*/;

	public final native void setOfflineSync(boolean offlineSync)
	/*-{
       this["offlineSync"] = offlineSync;
	}-*/;

	public final native boolean getAutomount()
	/*-{
	return this["automount"];
	}-*/;

	public final native void setAutomount(boolean automount)
	/*-{
       this["automount"] = automount;
	}-*/;

	public static native  JsContainerDescriptor create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
